# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.2.0

import winrt.system
from winui2._winui2_microsoft_ui_xaml_xamltypeinfo import (
    XamlControlsXamlMetaDataProvider,
)

__all__ = [
    "XamlControlsXamlMetaDataProvider",
]

